==> pwa_firebase-2.0.1.tar.gz: pwa_firebase/src/Form/PwaFirebaseCompose.php <==
<?php

namespace Drupal\pwa_firebase\Form;

use Drupal\Core\Database\Connection;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Markup;
use Drupal\Core\Url;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configuration form firebase.
 */
class PwaFirebaseCompose extends FormBase {

  /**
   * The database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected Connection $database;

  /**
   * {@inheritdoc}
   */
  public function __construct(Connection $database) {
    $this->database = $database;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database'),
    );
  }

  /**
   * Name of the config.
   *
   * @var string
   */
  public static $configName = 'pwa_firebase.compose';

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [self::$configName];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'pwa_firebase_compose_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('pwa_firebase.settings');
    if (empty($config->get('firebase_apiKey_id'))) {
      $routeNameCurrent = Url::fromRoute($this->getRouteMatch()->getRouteName())
        ->toString();
      $url = Url::fromRoute('pwa_firebase.configuration', [], ['query' => ['destination' => $routeNameCurrent]])
        ->setAbsolute()->toString();
      return new RedirectResponse($url);
    }

    $form['#attached']['library'][] = 'pwa_firebase/pwa_firebase_composer';
    $form['title'] = [
      "#type" => 'textfield',
      '#title' => $this->t('Title'),
      '#required' => TRUE,
      "#maxlength" => 1024,
    ];
    $form['pwa_firebase_phonebook'] = [
      '#type' => 'details',
      '#title' => $this->t('User list'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    ];
    $searchText = $this->t('Search');
    $form['pwa_firebase_phonebook']['checkAll'] = [
      '#type' => 'markup',
      '#markup' => Markup::create('
          <div class="form-inline">
              <div class="form-group">
                  <input type="checkbox" id="checkAll" class="form-check-input checkAll"/> <label for="checkAll">' . $this->t('Check All') . '</label>
               </div>
               <div class="form-group">
                  <input type="search" id="phonebook_search" class="phonebook_search form-control" placeholder="' . $searchText . '"/>
               </div>
           </div>'),
    ];

    $form['pwa_firebase_phonebook']["user"] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Users'),
      '#options' => $this->getUserHasToken(),
    ];
    $form['#tree'] = TRUE;
    $form['message'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Message'),
      '#required' => TRUE,
      "#maxlength" => 254,
    ];
    $form['url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('url'),
      "#maxlength" => 555,
    ];

    // Add a submit button that handles the submission of the form.
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Send notification'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $users = array_filter($values["pwa_firebase_phonebook"]["user"]);
    $firebaseService = \Drupal::service('pwa_firebase.send');
    if (empty($users)) {
      $firebaseService->sendMessageToAllUsers($values['title'], $values['message'], $values['url']);
      $this->messenger()
        ->addMessage($this->t("Notification sent to all users"));
    }
    else {
      foreach ($users as $user) {
        $firebaseService->sendMessageToUser($user, $values['title'], $values['message'], $values['url']);
      }
      $this->messenger()
        ->addMessage($this->t("Notification sent to selected users"));
    }
  }

  /**
   * Get the user available has a token.
   */
  private function getUserHasToken() {
    $query = $this->database->select('pwa_firebase', 'f');
    $query->fields('f', ['uid']);
    $userHasToken = $query->distinct()->execute()->fetchCol();

    $query = $this->database->select('users_field_data', 'u')
      ->fields('u', ['uid', 'name'])
      ->condition('status', 1);
    if (!empty($userHasToken)) {
      $query->condition('u.uid', $userHasToken, 'IN');
    }
    return $query->execute()->fetchAllKeyed(0, 1);
  }

}

==> pwa_firebase-2.0.4.tar.gz: pwa_firebase/src/Form/PwaFirebaseCompose.php <==
<?php

namespace Drupal\pwa_firebase\Form;

use Drupal\Core\Database\Connection;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Markup;
use Drupal\Core\Url;
use Drupal\pwa_firebase\Firebase;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configuration form firebase.
 */
class PwaFirebaseCompose extends FormBase {

  /**
   * The database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected Connection $database;

  /**
   * The firebase service.
   *
   * @var \Drupal\pwa_firebase\Firebase
   */
  private Firebase $firebase;

  /**
   * {@inheritdoc}
   */
  public function __construct(Connection $database, Firebase $firebase) {
    $this->database = $database;
    $this->firebase = $firebase;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database'),
      $container->get('pwa_firebase.send'),
    );
  }

  /**
   * Name of the config.
   *
   * @var string
   */
  public static $configName = 'pwa_firebase.compose';

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [self::$configName];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'pwa_firebase_compose_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('pwa_firebase.settings');
    if (empty($config->get('firebase_apiKey_id'))) {
      $routeNameCurrent = Url::fromRoute($this->getRouteMatch()->getRouteName())
        ->toString();
      $url = Url::fromRoute('pwa_firebase.configuration', [], ['query' => ['destination' => $routeNameCurrent]])
        ->setAbsolute()->toString();
      return new RedirectResponse($url);
    }

    $form['#attached']['library'][] = 'pwa_firebase/pwa_firebase_composer';
    $form['title'] = [
      "#type" => 'textfield',
      '#title' => $this->t('Title'),
      '#required' => TRUE,
      "#maxlength" => 1024,
    ];
    $form['pwa_firebase_phonebook'] = [
      '#type' => 'details',
      '#title' => $this->t('User list'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    ];
    $searchText = $this->t('Search');
    $form['pwa_firebase_phonebook']['checkAll'] = [
      '#type' => 'markup',
      '#markup' => Markup::create('
          <div class="form-inline">
              <div class="form-group">
                  <input type="checkbox" id="checkAll" class="form-check-input checkAll"/> <label for="checkAll">' . $this->t('Check All') . '</label>
               </div>
               <div class="form-group">
                  <input type="search" id="phonebook_search" class="phonebook_search form-control" placeholder="' . $searchText . '"/>
               </div>
           </div>'),
    ];

    $form['pwa_firebase_phonebook']["user"] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Users'),
      '#options' => $this->getUserHasToken(),
    ];
    $form['#tree'] = TRUE;
    $form['message'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Message'),
      '#required' => TRUE,
      "#maxlength" => 254,
    ];
    $form['url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('url'),
      "#maxlength" => 555,
    ];

    // Add a submit button that handles the submission of the form.
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Send notification'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $users = array_filter($values["pwa_firebase_phonebook"]["user"]);
    if (empty($users)) {
      $this->firebase->sendMessageToAllUsers($values['title'], $values['message'], $values['url']);
      $this->messenger()
        ->addMessage($this->t("Notification sent to all users"));
    }
    else {
      foreach ($users as $user) {
        $this->firebase->sendMessageToUser($user, $values['title'], $values['message'], $values['url']);
      }
      $this->messenger()
        ->addMessage($this->t("Notification sent to selected users"));
    }
  }

  /**
   * Get the user available has a token.
   */
  private function getUserHasToken() {
    $query = $this->database->select('pwa_firebase', 'f');
    $query->fields('f', ['uid']);
    $userHasToken = $query->distinct()->execute()->fetchCol();

    $query = $this->database->select('users_field_data', 'u')
      ->fields('u', ['uid', 'name'])
      ->condition('status', 1);
    if (!empty($userHasToken)) {
      $query->condition('u.uid', $userHasToken, 'IN');
    }
    return $query->execute()->fetchAllKeyed(0, 1);
  }

}
